@@ -2,6 +2,17 @@ import os
 from pathlib import Path
 from typing import Text
 
+from rich.progress import (
+    BarColumn,
+    Progress,
+    SpinnerColumn,
+    Task,
+    TextColumn,
+    TimeRemainingColumn,
+    TransferSpeedColumn,
+)
+from rich.text import Text as Text_render
+
 __NEURALSPACE_URL = "https://ns-platform-staging.uksouth.cloudapp.azure.com"
 NEURALSPACE_URL_ENV_VAR = "NEURALSPACE_URL"
 LOGIN_URL = "api/auth/login"
@@ -54,7 +65,9 @@ REGEX_FILE = "regex.csv"
 LOOKUP_FILE = "lookup.csv"
 
 # KEYS
-
+METADATA = "metadata"
+SUCCESS = "success"
+NEURALSPACE_HOME = "neuralspaceHome"
 DESCRIPTION = "description"
 PROJECT_ID = "projectId"
 LANGUAGE = "language"
@@ -86,13 +99,17 @@ CREATED_AT = "createdAt"
 ENTITIES = "entities"
 INTENT = "intent"
 EXAMPLE_ID = "exampleId"
+ENTITY_ID = "entityId"
 TEXT = "text"
 EXAMPLES = "examples"
 MODEL_NAME = "modelName"
 MODEL_ID_key = "model_id"
 MODEL_ID = "modelId"
+MODEL_IDS = "modelIDs"
 TRAINING_STATUS = "trainingStatus"
+DEPLOYED_STATUS = "deploymentStatus"
 COMPLETED = "Completed"
+DEPLOYED = "Deployed"
 TRAINING = "Training"
 FAILED = "Failed"
 TIMED_OUT = "Timed Out"
@@ -114,6 +131,14 @@ N_REPLICAS = "nReplicas"
 LAST_STATUS_UPDATED = "lastStatusUpdateAt"
 PARSED_RESPONSE = "parsedResponse"
 OUTPUT = "output"
+START_INDEX = "start_idx"
+END_INDEX = "end_idx"
+TIME = "time"
+FROM = "from"
+TO = "to"
+VALUE = "value"
+KEY_ID = "id"
+KEY_KEY = "key"
 YES = "Yes"
 NO = "No"
 ENTITY_TYPE = "entityType"
@@ -142,6 +167,7 @@ CONFIDENCE = "confidence"
 INTENT_RANKING = "intent_ranking"
 # supported entity types
 NER_TYPES = [PRE_TRAINED, LOOKUP, SYNONYM, REGEX]
+USER_DEFINED_ENTITY_TYPES = [LOOKUP, SYNONYM, REGEX]
 
 # Follow up Commands
 CREATE_PROJECT_COMMAND = "neuralspace nlu create-project --help"
@@ -157,6 +183,7 @@ APP_IS_INSTALLED = "App is already installed"
 
 # URLS
 LIST_ENTITY_URL = "api/nlu/v1/list/entity"
+PLATFORM_URL = "https://ns-platform-staging.uksouth.cloudapp.azure.com/#/platform/nlu/"
 
 # emojis
 BOOK = "📚"
@@ -201,3 +228,46 @@ GREEN_START = "[green]"
 GREEN_END = "[/green]"
 LOGO_HASH = ""
 ERROR = f"{RED_START}ERROR{RED_END}"
+
+# Rasa
+KEY_PROJECT_ID = "project_id"
+KEY_PROJECT_IDS = "project_ids"
+KEY_MODEL_IDS = "model_ids"
+KEY_MODEL_ID = "model_id"
+COMPONENT_CONFIG = "component_config"
+KEY_PROJECT_DETAILS = "project_details"
+KEY_PATH_TO_PROJECT_ID = "project_path"
+KEY_RASA = "rasa"
+NS_RASA_METADATA_FILE = "metadata.json"
+KEY_DATA = "data"
+KEY_AUTH = "auth"
+KEY_REPLICAS = "replicas"
+ENTITY_KEY_DELEMETER = "$$$###"
+EXAMPLES_FILE = "examples.json"
+ENTITIES_FILE = "entities.json"
+PIPELINE = "pipeline"
+COMPONENT_CLASS = "neuralspace.components.rasa.neuralspace.NeuralSpaceNLP"
+
+
+# PROGRESS BAR
+class CustomisedTransferSpeedColumn(TransferSpeedColumn):
+    def render(self, task: Task) -> Text_render:
+        """Show data transfer speed."""
+        speed = task.finished_speed or task.speed
+        if speed is None:
+            return Text_render("?", style="progress.data.speed")
+        return Text_render(f"{speed: .2f} examples/s", style="progress.data.speed")
+
+
+progress_bar = Progress(
+    SpinnerColumn(),
+    TextColumn(
+        "[orange3]Uploading...[/orange3]"
+        " [dark_green]{task.completed}[/dark_green]/[dark_green]{task.total}[/dark_green]"
+    ),
+    BarColumn(bar_width=50),
+    "[progress.percentage]{task.percentage:>3.0f}%",
+    TimeRemainingColumn(),
+    CustomisedTransferSpeedColumn(),
+    "[orange3][progress.description]{task.description}[/orange3]",
+)
