@@ -21,14 +21,6 @@ from neuralspace.constants import (
     VALUE,
 )
 from neuralspace.nlu.converters.rasaconverter import RasaConverter
-from neuralspace.nlu.utils import (
-    auto_tag_lookup,
-    auto_tag_pretrained_entities,
-    auto_tag_regex,
-    map_entities,
-    remove_entity_duplicates,
-    remove_nlu_duplicates,
-)
 
 
 class DialogflowConverter(RasaConverter):
@@ -101,29 +93,4 @@ class DialogflowConverter(RasaConverter):
             self.synonym_data += self.__synonym_converter(data)
             self.nlu_data += self.__nlu_data_converter(data)
 
-        if self.entity_mapping:
-            self.nlu_data = map_entities(self.nlu_data, self.entity_mapping)
-
-        if self.auto_tag_entities:
-            self.nlu_data = auto_tag_pretrained_entities(self.nlu_data, self.language)
-            self.nlu_data = auto_tag_lookup(self.nlu_data, self.lookup_data)
-            self.nlu_data = auto_tag_regex(self.nlu_data, self.regex_data)
-        self.set_data_type(dataset_type)
-        self.nlu_data = remove_nlu_duplicates(self.nlu_data)
-        self.lookup_data = remove_entity_duplicates(
-            remove_nlu_duplicates(self.lookup_data)
-        )
-        self.regex_data = remove_entity_duplicates(
-            remove_nlu_duplicates(self.regex_data)
-        )
-        self.synonym_data = remove_entity_duplicates(
-            remove_nlu_duplicates(self.synonym_data)
-        )
-        output_directory.mkdir(parents=True, exist_ok=True)
-        self.save_converted_data(
-            output_directory=output_directory,
-            nlu_data=self.nlu_data,
-            lookup_data=self.lookup_data,
-            synonym_data=self.synonym_data,
-            regex_data=self.regex_data,
-        )
+        self.post_process(dataset_type=dataset_type, output_directory=output_directory)
