@@ -55,12 +55,20 @@ from neuralspace.constants import (
     neuralspace_url,
 )
 
-console = Console()
+
 logger = logging.getLogger("rich")
+console = Console()
 
 
 def setup_logger(log_level: Text):
-    logging.basicConfig(level=log_level, handlers=[RichHandler(level=log_level)])
+    global logger
+    logging.basicConfig(level=log_level, handlers=[RichHandler(level=logging.INFO)])
+    if log_level == "INFO":
+        logger.level = logging.INFO
+    elif log_level == "DEBUG":
+        logger.level = logging.DEBUG
+    elif log_level == "ERROR":
+        logger.level = logging.ERROR
 
 
 def get_logo():
